@@ -69,7 +69,11 @@ COLLECT_LOGS_COMMANDS = {
     'ip_addr': ['ip', 'addr'],
     'lshw': ['lshw', '-quiet', '-json'],
     'lsblk': ['lsblk', '--all', '-o%s' % ','.join(LSBLK_COLUMNS)],
+    'lsblk-full': ['lsblk', '--all', '--bytes', '--output-all', '--pairs'],
     'mdstat': ['cat', '/proc/mdstat'],
+    'mount': ['mount'],
+    'parted': ['parted', '-l'],
+    'multipath': ['multipath', '-ll'],
 }
 
 
